.. cronian documentation master file, created by
   sphinx-quickstart on Mon Jul 21 17:02:01 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Cronian documentation
=====================

Welcome to the documentation for cronian! Cronian (pronounced 'kroh-nian` is a Python package for
building copper plate optimization models in `Pyomo <https://www.pyomo.org>`_ to optimize
flexibility scheduling in multi-carrier integrated energy systems. You can specify your entire
co-optimization model using simple `YAML` and `CSV` files. Alternatively, you can use the modular
architecture to build standalone models of generators and consumers/prosumers to use as part of
other methods such as distributed optimization or agent-based simulations.

Cronian was developed as part of the `DEMOSES <https://www.nwo.nl/en/projects/esi2019004>`_ project,
funded by NWO under Grant ID: ESI.2019.004.

Last updated: (|today|)

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   install
   example-usage
